@@ -1,7 +1,7 @@
 from .condition import Condition
 from .tools import peer, random_id
-from .vk import Auth, Keyboard
+from .vk import Api, LongPoll, Keyboard, Button
 from .exception import VkErr
 from .payload import payload
-from .DotDict import DotDict
-from .cond import *
+from .dot_dict import DotDict
+from vk_dev import cond
